#[non_exhaustive]pub struct RemoveRegionInput {
pub instance_arn: Option<String>,
pub region_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_arn: Option<String>The Amazon Resource Name (ARN) of the IAM Identity Center instance.
region_name: Option<String>The name of the Amazon Web Services Region to remove from the IAM Identity Center instance. The Region name must be 1-32 characters long and follow the pattern of Amazon Web Services Region names (for example, us-east-1). The primary Region cannot be removed.
Implementations
Sourceimpl RemoveRegionInput
impl RemoveRegionInput
Sourcepub fn instance_arn(&self) -> Option<&str>
pub fn instance_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM Identity Center instance.
Sourcepub fn region_name(&self) -> Option<&str>
pub fn region_name(&self) -> Option<&str>
The name of the Amazon Web Services Region to remove from the IAM Identity Center instance. The Region name must be 1-32 characters long and follow the pattern of Amazon Web Services Region names (for example, us-east-1). The primary Region cannot be removed.
Sourceimpl RemoveRegionInput
impl RemoveRegionInput
Sourcepub fn builder() -> RemoveRegionInputBuilder
pub fn builder() -> RemoveRegionInputBuilder
Creates a new builder-style object to manufacture RemoveRegionInput.