#[non_exhaustive]pub struct RegionMetadataBuilder { /* private fields */ }Expand description
A builder for RegionMetadata.
Implementations
Sourceimpl RegionMetadataBuilder
impl RegionMetadataBuilder
Sourcepub fn region_name(self, input: impl Into<String>) -> Self
pub fn region_name(self, input: impl Into<String>) -> Self
The Amazon Web Services Region name.
Sourcepub fn set_region_name(self, input: Option<String>) -> Self
pub fn set_region_name(self, input: Option<String>) -> Self
The Amazon Web Services Region name.
Sourcepub fn get_region_name(&self) -> &Option<String>
pub fn get_region_name(&self) -> &Option<String>
The Amazon Web Services Region name.
Sourcepub fn status(self, input: RegionStatus) -> Self
pub fn status(self, input: RegionStatus) -> Self
The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
Sourcepub fn set_status(self, input: Option<RegionStatus>) -> Self
pub fn set_status(self, input: Option<RegionStatus>) -> Self
The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
Sourcepub fn get_status(&self) -> &Option<RegionStatus>
pub fn get_status(&self) -> &Option<RegionStatus>
The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
Sourcepub fn added_date(self, input: DateTime) -> Self
pub fn added_date(self, input: DateTime) -> Self
The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
Sourcepub fn set_added_date(self, input: Option<DateTime>) -> Self
pub fn set_added_date(self, input: Option<DateTime>) -> Self
The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
Sourcepub fn get_added_date(&self) -> &Option<DateTime>
pub fn get_added_date(&self) -> &Option<DateTime>
The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
Sourcepub fn is_primary_region(self, input: bool) -> Self
pub fn is_primary_region(self, input: bool) -> Self
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
Sourcepub fn set_is_primary_region(self, input: Option<bool>) -> Self
pub fn set_is_primary_region(self, input: Option<bool>) -> Self
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
Sourcepub fn get_is_primary_region(&self) -> &Option<bool>
pub fn get_is_primary_region(&self) -> &Option<bool>
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
Sourcepub fn build(self) -> RegionMetadata
pub fn build(self) -> RegionMetadata
Consumes the builder and constructs a RegionMetadata.