#[non_exhaustive]pub struct RegionMetadata {
pub region_name: Option<String>,
pub status: Option<RegionStatus>,
pub added_date: Option<DateTime>,
pub is_primary_region: bool,
}Expand description
Contains information about an enabled Region of an IAM Identity Center instance, including the Region name, status, date added, and whether it is the primary Region.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.region_name: Option<String>The Amazon Web Services Region name.
status: Option<RegionStatus>The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
added_date: Option<DateTime>The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
is_primary_region: boolIndicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
Implementations
Sourceimpl RegionMetadata
impl RegionMetadata
Sourcepub fn region_name(&self) -> Option<&str>
pub fn region_name(&self) -> Option<&str>
The Amazon Web Services Region name.
Sourcepub fn status(&self) -> Option<&RegionStatus>
pub fn status(&self) -> Option<&RegionStatus>
The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
Sourcepub fn added_date(&self) -> Option<&DateTime>
pub fn added_date(&self) -> Option<&DateTime>
The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
Sourcepub fn is_primary_region(&self) -> bool
pub fn is_primary_region(&self) -> bool
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
Sourceimpl RegionMetadata
impl RegionMetadata
Sourcepub fn builder() -> RegionMetadataBuilder
pub fn builder() -> RegionMetadataBuilder
Creates a new builder-style object to manufacture RegionMetadata.